@@ -1,46 +1,48 @@
-require 5;
 package Pod::Simple::HTML;
 use strict;
+use warnings;
 use Pod::Simple::PullParser ();
-use vars qw(
-  @ISA %Tagmap $Computerese $LamePad $Linearization_Limit $VERSION
-  $Perldoc_URL_Prefix $Perldoc_URL_Postfix $Man_URL_Prefix $Man_URL_Postfix
-  $Title_Prefix $Title_Postfix $HTML_EXTENSION %ToIndex
-  $Doctype_decl  $Content_decl
-);
-@ISA = ('Pod::Simple::PullParser');
-$VERSION = '3.42';
+our @ISA = ('Pod::Simple::PullParser');
+our $VERSION = '3.45';
 BEGIN {
   if(defined &DEBUG) { } # no-op
   elsif( defined &Pod::Simple::DEBUG ) { *DEBUG = \&Pod::Simple::DEBUG }
   else { *DEBUG = sub () {0}; }
 }
 
-$Doctype_decl ||= '';  # No.  Just No.  Don't even ask me for it.
+our $Doctype_decl ||= '';  # No.  Just No.  Don't even ask me for it.
  # qq{<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
  #    "http://www.w3.org/TR/html4/loose.dtd">\n};
 
-$Content_decl ||=
+our $Content_decl ||=
  q{<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" >};
 
+our $HTML_EXTENSION;
 $HTML_EXTENSION = '.html' unless defined $HTML_EXTENSION;
+our $Computerese;
 $Computerese =  "" unless defined $Computerese;
+our $LamePad;
 $LamePad = '' unless defined $LamePad;
 
+our $Linearization_Limit;
 $Linearization_Limit = 120 unless defined $Linearization_Limit;
  # headings/items longer than that won't get an <a name="...">
+our $Perldoc_URL_Prefix;
 $Perldoc_URL_Prefix  = 'https://metacpan.org/pod/'
  unless defined $Perldoc_URL_Prefix;
+our $Perldoc_URL_Postfix;
 $Perldoc_URL_Postfix = ''
  unless defined $Perldoc_URL_Postfix;
 
 
-$Man_URL_Prefix  = 'http://man.he.net/man';
-$Man_URL_Postfix = '';
+our $Man_URL_Prefix  = 'http://man.he.net/man';
+our $Man_URL_Postfix = '';
 
+our $Title_Prefix;
 $Title_Prefix  = '' unless defined $Title_Prefix;
+our $Title_Postfix;
 $Title_Postfix = '' unless defined $Title_Postfix;
-%ToIndex = map {; $_ => 1 } qw(head1 head2 head3 head4 ); # item-text
+our %ToIndex = map {; $_ => 1 } qw(head1 head2 head3 head4 ); # item-text
   # 'item-text' stuff in the index doesn't quite work, and may
   # not be a good idea anyhow.
 
@@ -63,13 +65,13 @@ __PACKAGE__->_accessorize(
  'batch_mode_current_level',
     # When in batch mode, how deep the current module is: 1 for "LWP",
     #  2 for "LWP::Procotol", 3 for "LWP::Protocol::GHTTP", etc
-    
+
  'title_prefix',  'title_postfix',
   # What to put before and after the title in the head.
   # Should already be &-escaped
 
  'html_h_level',
-  
+
  'html_header_before_title',
  'html_header_after_title',
  'html_footer',
@@ -89,7 +91,7 @@ __PACKAGE__->_accessorize(
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 my @_to_accept;
 
-%Tagmap = (
+our %Tagmap = (
   'Verbatim'  => "\n<pre$Computerese>",
   '/Verbatim' => "</pre>\n",
   'VerbatimFormatted'  => "\n<pre$Computerese>",
@@ -104,7 +106,7 @@ my @_to_accept;
 
   'Data'  => "\n",
   '/Data' => "\n",
-  
+
   'head1' => "\n<h1>",  # And also stick in an <a name="...">
   'head2' => "\n<h2>",  #  ''
   'head3' => "\n<h3>",  #  ''
@@ -152,7 +154,7 @@ my @_to_accept;
       teletype=tt
     ]  # no point in providing a way to get <q>...</q>, I think
   ),
-  
+
   '/item-bullet' => "</li>$LamePad\n",
   '/item-number' => "</li>$LamePad\n",
   '/item-text'   => "</a></dt>$LamePad\n",
@@ -256,7 +258,7 @@ sub do_beginning {
   my $self = $_[0];
 
   my $title;
-  
+
   if(defined $self->force_title) {
     $title = $self->force_title;
     DEBUG and print STDERR "Forcing title to be $title\n";
@@ -272,13 +274,13 @@ sub do_beginning {
     if(defined $title and $title =~ m/\S/) {
       $title = $self->title_prefix . esc($title) . $self->title_postfix;
     } else {
-      $title = $self->default_title;    
+      $title = $self->default_title;
       $title = '' unless defined $title;
       DEBUG and print STDERR "Title defaults to $title\n";
     }
   }
 
-  
+
   my $after = $self->html_header_after_title  || '';
   if($self->html_css) {
     my $link =
@@ -409,10 +411,10 @@ sub index_as_html {
   # This is meant to be called AFTER the input document has been parsed!
 
   my $points = $self->{'PSHTML_index_points'} || [];
-  
+
   @$points > 1 or return qq[<div class='indexgroupEmpty'></div>\n];
    # There's no point in having a 0-item or 1-item index, I dare say.
-  
+
   my(@out) = qq{\n<div class='indexgroup'>};
   my $level = 0;
 
@@ -429,7 +431,7 @@ sub index_as_html {
         $target_level = $level;  # no change needed
       }
     }
-    
+
     # Get to target_level by opening or closing ULs
     while($level > $target_level)
      { --$level; push @out, ("  " x $level) . "</ul>"; }
@@ -439,7 +441,7 @@ sub index_as_html {
 
     $previous_tagname = $tagname;
     next unless $level;
-    
+
     $indent = '  '  x $level;
     push @out, sprintf
       "%s<li class='indexItem indexItem%s'><a href='#%s'>%s</a>",
@@ -458,7 +460,7 @@ sub _do_middle_main_loop {
   my $tagmap = $self->{'Tagmap'};
 
   $self->__adjust_html_h_levels;
-  
+
   my($token, $type, $tagname, $linkto, $linktype);
   my @stack;
   my $dont_wrap = 0;
@@ -469,7 +471,7 @@ sub _do_middle_main_loop {
     if( ($type = $token->type) eq 'start' ) {
       if(($tagname = $token->tagname) eq 'L') {
         $linktype = $token->attr('type') || 'insane';
-        
+
         $linkto = $self->do_link($token);
 
         if(defined $linkto and length $linkto) {
@@ -489,7 +491,7 @@ sub _do_middle_main_loop {
           push @to_unget, $self->get_token;
           last if $to_unget[-1]->is_end
               and $to_unget[-1]->tagname eq $tagname;
-          
+
           # TODO: support for X<...>'s found in here?  (maybe hack into linearize_tokens)
         }
 
@@ -502,7 +504,7 @@ sub _do_middle_main_loop {
                 ? " href='#___top' title='click to go to top of document'\n"
                 : "\n";
         }
-        
+
         if(defined $name) {
           my $esc = esc(  $self->section_name_tidy( $name ) );
           print $fh qq[name="$esc"];
@@ -512,7 +514,7 @@ sub _do_middle_main_loop {
            if $ToIndex{ $tagname };
             # Obviously, this discards all formatting codes (saving
             #  just their content), but ahwell.
-           
+
         } else {  # ludicrously long, so nevermind
           DEBUG and print STDERR "Linearized ", scalar(@to_unget),
            " tokens, but it was too long, so nevermind.\n";
@@ -532,7 +534,7 @@ sub _do_middle_main_loop {
         (my $text = $next->text) =~ s/\n\z//;
         print $fh $text, "\n";
         next;
-       
+
       } else {
         if( $tagname =~ m/^over-/s ) {
           push @stack, '';
@@ -633,7 +635,7 @@ sub do_pod_link {
 
   DEBUG and printf STDERR "Resolving \"%s\" \"%s\"...\n",
    $to || "(nil)",  $section || "(nil)";
-   
+
   {
     # An early hack:
     my $complete_url = $self->resolve_pod_link_by_table($to, $section);
@@ -654,7 +656,7 @@ sub do_pod_link {
       DEBUG > 1
        and print STDERR "resolve_pod_link_by_table(T) gives $there\n";
     } else {
-      $there = 
+      $there =
         $self->resolve_pod_page_link($to, $section);
          # (I pass it the section value, but I don't see a
          #  particular reason it'd use it.)
@@ -673,7 +675,7 @@ sub do_pod_link {
 
   my $out = (defined $to and length $to) ? $to : '';
   $out .= "#" . $section if defined $section and length $section;
-  
+
   unless(length $out) { # sanity check
     DEBUG and printf STDERR "Oddly, couldn't resolve \"%s\" \"%s\"...\n",
      $to || "(nil)",  $section || "(nil)";
@@ -681,7 +683,7 @@ sub do_pod_link {
   }
 
   DEBUG and print STDERR "Resolved to $out\n";
-  return $out;  
+  return $out;
 }
 
 
@@ -715,13 +717,13 @@ sub manpage_url_escape  { shift->general_url_escape(@_) }
 
 sub general_url_escape {
   my($self, $string) = @_;
- 
+
   $string =~ s/([^\x00-\xFF])/join '', map sprintf('%%%02X',$_), unpack 'C*', $1/eg;
      # express Unicode things as urlencode(utf(orig)).
-  
+
   # A pretty conservative escaping, behoovey even for query components
   #  of a URL (see RFC 2396)
-  
+
   if ($] ge 5.007_003) {
     $string =~ s/([^-_\.!~*()abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/sprintf('%%%02X',utf8::native_to_unicode(ord($1)))/eg;
   } else { # Is broken for non-ASCII platforms on early perls
@@ -729,7 +731,7 @@ sub general_url_escape {
   }
    # Yes, stipulate the list without a range, so that this can work right on
    #  all charsets that this module happens to run under.
-  
+
   return $string;
 }
 
@@ -751,10 +753,10 @@ sub resolve_pod_page_link_singleton_mode {
   my($self, $it) = @_;
   return undef unless defined $it and length $it;
   my $url = $self->pagepath_url_escape($it);
-  
+
   $url =~ s{::$}{}s; # probably never comes up anyway
   $url =~ s{::}{/}g unless $self->perldoc_url_prefix =~ m/\?/s; # sane DWIM?
-  
+
   return undef unless length $url;
   return $self->perldoc_url_prefix . $url . $self->perldoc_url_postfix;
 }
@@ -823,7 +825,7 @@ sub resolve_pod_link_by_table {
 sub linearize_tokens {  # self, tokens
   my $self = shift;
   my $out = '';
-  
+
   my $t;
   while($t = shift @_) {
     if(!ref $t or !UNIVERSAL::can($t, 'is_text')) {
@@ -945,7 +947,7 @@ Include a single javascript source:
 
   $p->html_javascript('http://abc.com/a.js');
 
-Or insert multiple javascript source in the header 
+Or insert multiple javascript source in the header
 (or for that matter include anything, thought this is not recommended)
 
   $p->html_javascript('
@@ -980,8 +982,8 @@ The following variables need to be set B<before> the call to the ->new construct
 
 Set the string that is included before the opening <html> tag:
 
-  $Pod::Simple::HTML::Doctype_decl = qq{<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" 
-	 "http://www.w3.org/TR/html4/loose.dtd">\n};
+  $Pod::Simple::HTML::Doctype_decl = qq{<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+    "http://www.w3.org/TR/html4/loose.dtd">\n};
 
 Set the content-type in the HTML head: (defaults to ISO-8859-1)
 
@@ -1066,7 +1068,7 @@ one needs to override some of the methods:
     my ($self, $link) = @_;
 
     say $link->tagname;          # will be L for links
-    say $link->attr('to');       # 
+    say $link->attr('to');       #
     say $link->attr('type');     # will be 'pod' always
     say $link->attr('section');
 
@@ -1117,7 +1119,7 @@ pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
 L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+to clone L<https://github.com/perl-pod/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
